<?php

namespace App\Http\Controllers;

use App\Models\Frete;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;

class FreteController extends Controller
{

    private const TIPOS_EXCLUIDOS = [
        // Itens originais
        "a combinar",
        "abacaxi",
        "abastecimento ...",
        "agua mineral",
        "aliminio",
        "aluminio",
        "aparerelhos de a...",
        "achatador de p...",
        "aço",
        "confecções",
        "melancia",
        "palletts",
        "roupeiro de aç...",
        "shingle e made...",
        "spa e deck",
        "sucata eletrôn...",
        "sa",
        "pet",
        "pedras decorat...",
        "peças de brita...",
        "paletes novos ...",
        "moveis em alum...",
        "mix nutri",
        "manta termica",
        "informações ad...",
        "andaimes e ace...",
        "agregamento - ...",
        "agregamento ca...",
        "alcool gel",
        "algodão em plu...",
        "alimenticio",
        "amarrado tubo",
        "aparelho de ac...",
        "aparelho de gi...",
        "aparelhos para...",
        "aquecedor",
        "arame",
        "arga assentved...",
        "arga massa",
        "argamassa",
        "argamassa fass...",
        "argamassas",
        "asfalto em sac...",
        "asfalto ensaca...",
        "asfalto frio",
        "azulejos",
        "baldes de tint...",
        "bancada de piz...",
        "bancos",
        "banheira de hi...",
        "barras e tubos...",
        "bebidas",
        "beliches desmo...",
        "big beg",
        "bigbeg",
        "blindagens",
        "bobina de espu...",
        "bobina de plás...",
        "bobinas",
        "bobinas plásti...",
        "bomba de combu...",
        "bombona",
        "brimquedos",
        "briquete de ma...",
        "cabo de fibra ...",
        "cabos",
        "cabos de vasso...",
        "cabos para vas...",
        "caco miracema",
        "cadeira",
        "café",
        "caixa",
        "caixa com prod...",
        "caixa de agua ...",
        "caixa de l",
        "caixa de madei...",
        "caixa plastica...",
        "caixas",
        "caixas dagua",
        "caixas de made...",
        "caixas irrigaç...",
        "caixas paletiz...",
        "caixas plastic...",
        "caixotes",
        "cal",
        "calcario",
        "cama empilhave...",
        "canos pvc",
        "capota de fibr...",
        "carbonato",
        "cargas gerais",
        "caroço",
        "cebola",
        "ceramica",
        "cerveja",
        "cha diamadeu c...",
        "chapa",
        "chapa de aço",
        "chapa de madei...",
        "chapas",
        "chapas de comp...",
        "chapas de made...",
        "cimento",
        "cimento bigbeg",
        "cimento em pa...",
        "cimento em pal...",
        "cimento ensaca...",
        "cimento paleti...",
        "cimento pallet...",
        "cimento zebu",
        "clameshell",
        "climatizador e...",
        "coca cola",
        "cocho de plast...",
        "cola para pneu",
        "colchao casal",
        "colchões de so...",
        "colchões hospi...",
        "colchonete de ...",
        "colchonetes fi...",
        "colchonetes pe...",
        "compensado",
        "complemento",
        "complemento pa...",
        "complemento pe...",
        "complemento tr...",
        "complementq",
        "concertina",
        "cone prfv - fi...",
        "conexões de fe...",
        "conjunto de so...",
        "conservador ho...",
        "construçaõ",
        "container",
        "container almo...",
        "container de o...",
        "container ibc",
        "container marí...",
        "container reef...",
        "container vazi...",
        "cxs",
        "detergente",
        "detergentes",
        "dezessete colc...",
        "diverso",
        "diversos",
        "dois caixotes ...",
        "dois carro de ...",
        "dois colchões ...",
        "dois container...",
        "dormente de ma...",
        "duas poltronas...",
        "elementos filt...",
        "embalagem de r...",
        "embalagem para...",
        "embalagens",
        "embalagens fle...",
        "escoras metali...",
        "espuma",
        "esquadrilhas",
        "estocador de a...",
        "estrutura",
        "etiquetas",
        "eucalipito",
        "eucalipto",
        "fardos",
        "farelo",
        "farelo de arro...",
        "farelo de soja",
        "fechamento- ta...",
        "feijao",
        "feno",
        "fertilizante",
        "fios",
        "fogão industri...",
        "folder",
        "fornos industr...",
        "forro",
        "fracionado",
        "freezer vertic...",
        "frete teste",
        "garrafa",
        "garrafas de pl...",
        "garrafas plást...",
        "garrafinha col...",
        "gênero aliment...",
        "grade",
        "grama",
        "grama em placa...",
        "grama esmerald...",
        "grampo pino",
        "higiene e limp...",
        "hospitalar ins...",
        "isopor",
        "itens para aca...",
        "jogo de mesa c...",
        "jogo de mesa e...",
        "laje alveolar",
        "lamina sinteri...",
        "leite",
        "leite em pó",
        "madeira",
        "madeira de pin...",
        "madeira pra fa...",
        "madeira serrad...",
        "madeirite",
        "matéria prima",
        "material de co...",
        "material de pi...",
        "material espor...",
        "mesa",
        "mesa de futmes...",
        "mesa de inox",
        "mesa de madeir...",
        "milho",
        "móveis",
        "movéis pára al...",
        "mudança",
        "óleo",
        "oleo hidraulic...",
        "oleo vegetal",
        "pacote",
        "pacotes",
        "pacotes com co...",
        "paineis",
        "palet novos",
        "palete",
        "palete vazio",
        "paletes",
        "paletizado",
        "pallet",
        "pallet argamas...",
        "palletizado",
        "pallets",
        "pallets de mad...",
        "pé de banco em...",
        "peça",
        "peça automotiv...",
        "peca de ferro",
        "pecas",
        "peças automoti...",
        "peças de aço -...",
        "peças de borra...",
        "peças de concr...",
        "peças de fómic...",
        "pecas de silo ...",
        "peças em geral",
        "peças ind com ...",
        "peças metálica...",
        "pecas para sil...",
        "peças para tra...",
        "pedra",
        "pedra decorati...",
        "pedra em caixa...",
        "pedra paletiza...",
        "pedra para por...",
        "pedras",
        "pedras são tom...",
        "pellet",
        "perf",
        "perf chapa",
        "perfil de alum...",
        "perfil em alum...",
        "peso de academ...",
        "piso cerâmico",
        "piso de borrac...",
        "piso de concre...",
        "piso em granit...",
        "piso em mármor...",
        "piso emborrach...",
        "pisos",
        "placa solar",
        "plastico",
        "playgrounds",
        "pluma",
        "pneu de máquin...",
        "polipropileno",
        "ponteira de tr...",
        "porta de alumi...",
        "portas",
        "poste de alumi...",
        "postes de conc...",
        "pp",
        "prancha de mad...",
        "pre moldado",
        "pregos",
        "produto alimen...",
        "produto de lim...",
        "produtos de ja...",
        "produtos de li...",
        "produtos de ma...",
        "produtos sider...",
        "puffs feitos ...",
        "quatro sofás d...",
        "ração de pet",
        "ração pet",
        "rafia",
        "redutor de tra...",
        "reservatorio i...",
        "reservatório m...",
        "resfriado de l...",
        "resfriador de ...",
        "revestimento e...",
        "revestimentos",
        "revestimentos ...",
        "rolo de tapede",
        "rolo faca",
        "rotopec luma ...",
        "sacaria de sem...",
        "saco",
        "sacos",
        "sacos com colc...",
        "sal",
        "sal mineral",
        "selador",
        "semente",
        "semente para p...",
        "skid",
        "soja",
        "soja em grãos",
        "spa de hidroma...",
        "spa hidro",
        "subsolador civ...",
        "substrato",
        "substratos",
        "sucata",
        "sucata de onib...",
        "tanque",
        "tanque caixa",
        "tanque de agua...",
        "tanque plastic...",
        "tanque polieti...",
        "tanque rodoviá...",
        "tanques dágua",
        "tanques de agu...",
        "tapete de borr...",
        "tela soldada",
        "telas de ferro",
        "telha",
        "telha brasilit",
        "telha eternit",
        "telhas",
        "telhas e paine...",
        "telhas reciclá...",
        "telhas termica",
        "telhas termoac...",
        "tijolo",
        "tijolos",
        "touco de dorme...",
        "tres pacotes d...",
        "trigo",
        "trilhos de alu...",
        "trinta colchõe...",
        "tubo de irriga...",
        "tubos",
        "tubos de aço",
        "tubos de ferro",
        "tubos de pvc",
        "tubos finos de...",
        "um colchão de ...",
        "um conjunto de...",
        "um palete de p...",
        "um rolo de tec...",
        "um sofá de trê...",
        "um sofá pequen...",
        "um tanque de a...",
        "uma cadeira de...",
        "unidades",
        "unidades de co...",
        "uniformes",
        "varão de corti...",
        "viga de madeir...",
        "viga mista",
        "vontorantim",
        "caçambas de en...",
        "caçambas para ...",
        "carrinho de ma...",
        "isoladores par...",
        "secadora de ro...",
        // Novos itens a incluir
        "acessório de g...",
        "acessorios de ...",
        "açúcar",
        "adubo",
        "algodao",
        "almofadas de e...",
        "andaime escora",
        "anilhas",
        "aparelho acade...",
        "ardosia palete...",
        "argamassa - sa...",
        "argamassa em p...",
        "armarios de aç...",
        "baldes vazios",
        "banheiras de h...",
        "base de box",
        "bastão de made...",
        "bau",
        "bebedouro fran...",
        "bertonite",
        "betoneiras",
        "big bag",
        "big bag adubo",
        "bobinas de lon...",
        "bomba a vácuo ...",
        "brinquedo de i...",
        "brinquedo de p...",
        "cacos",
        "cadeiras",
        "cadeiras escri...",
        "cadeiras pront...",
        "caixa com gram...",
        "caixa de agua",
        "caixa de bebed...",
        "caixa de cozin...",
        "caixa de papel",
        "caixa papelão",
        "caixas bolsas ...",
        "caixas de agua",
        "cama box casal",
        "carroceria gra...",
        "casquin",
        "chapas de ferr...",
        "cimento mizu",
        "cimento refrat...",
        "coco verde",
        "colchão hospit...",
        "colchonete",
        "coletor de lix...",
        "compensados",
        "cone",
        "container de s...",
        "container gera...",
        "containers de ...",
        "conteiner",
        "corrente",
        "couro salgado",
        "defensivos agr...",
        "degraus de mad...",
        "detergente em ...",
        "diveros",
        "dois contêiner...",
        "duto de entulh...",
        "dvs",
        "eletroduto",
        "elevador de ca...",
        "embalagens lon...",
        "escritorio",
        "esfera de aço ...",
        "estaca de conc...",
        "esteira",
        "esteira e pren...",
        "estrutura metá...",
        "estruturas de ...",
        "fardo de embal...",
        "ferragens para...",
        "ferro",
        "forma metálica",
        "formas de aço",
        "forno industri...",
        "fraldas",
        "garrafas",
        "gesso",
        "gesso em pó en...",
        "hortifruti",
        "lata de tinta",
        "lavadora de ro...",
        "linha leve da ...",
        "lixeiras",
        "lonna geomembr...",
        "madeira paleti...",
        "madeiras",
        "mangueira",
        "mangueira para...",
        "materiais de c...",
        "material const...",
        "material de st...",
        "mercadoria",
        "mesa de triage...",
        "pet - rações e...",
        "volume pequen...",
        "agregamento dh...",
        "pvc moído",
        "paletes vazio",
        "mesa e serra",
        "mistura bolo",
        "modulo de cons...",
        "modulo de escr...",
        "namoradeira - ...",
        "no break - bom...",
        "outros",
        "pacotes com t...",
        "paleteira elet...",
        "pallets vazio",
        "pallets vazios",
        "papelão",
        "parafina",
        "partes e paças",
        "peça de implem...",
        "peça de maquin...",
        "peça de trator",
        "pecas de onibu...",
        "peças de plata...",
        "peças diversas",
        "peças para obr...",
        "peças plastica...",
        "pedaços de mdf",
        "pedra mineira",
        "perfil e telha...",
        "perfil metalic...",
        "perfis",
        "piso vinilico",
        "pisos de borra...",
        "pisos e revest...",
        "pisso laminado",
        "placa de facha...",
        "pneu de carro",
        "poltronas",
        "postes",
        "prego",
        "premoldados",
        "produto químic...",
        "produtos indus...",
        "quatro poltron...",
        "redutor e mola",
        "redutor mola",
        "refil de madei...",
        "rotuladeira",
        "roupeiros de a...",
        "sacaria",
        "sacarias",
        "sacas sementes",
        "sacos e peneit...",
        "sementes",
        "sofá",
        "soja x",
        "sucata automot...",
        "suplemento min...",
        "suportes ar co...",
        "tampas",
        "tanque de agua",
        "tanque tipo ca...",
        "tatame",
        "telha de fibro...",
        "telha e pvc",
        "telha paletiza...",
        "telhas eternit",
        "telhas imbrali...",
        "tenda",
        "tenda pequena",
        "tenda piramid...",
        "tenda piramida...",
        "tendas",
        "tendas piramid...",
        "tinta a base ...",
        "tronco de cont...",
        "tubos curvas e...",
        "tubos e conexõ...",
        "um big bag de ...",
        "uma barra",
        "unidade",
        "utensilios coz...",
        "vasos de louça...",
        "vigas",
        "volume",
        "aparelhos de a...",
        "areia",
        "areia de quart...",
        "asfalto",
        "assoalho pinus",
        "banco de madei...",
        "banqueta",
        "basculante",
        "bike academia",
        "bobina de aço",
        "bobina de borr...",
        "bobinão - car...",
        "bombas para ir...",
        "borrachas pica...",
        "cadeira de mad...",
        "caixa de papel...",
        "caixaria",
        "caixas de sapa...",
        "carga geral",
        "carla",
        "carpete",
        "chapas de aço",
        "chapas ferro",
        "cinco pacotes ...",
        "clinquer-calcá...",
        "complemento di...",
        "complemento me...",
        "concreto vigua",
        "conjunto de pe...",
        "container escr...",
        "contra peso gu...",
        "cordoalha",
        "correias para ...",
        "ddgs",
        "dessecador",
        "dez volumes de...",
        "diversas",
        "diversos ca...",
        "diversos gelei...",
        "divesos",
        "divisoria",
        "eixo e transmi...",
        "eletrodutos co...",
        "eletronicos - ...",
        "elevação pelvi...",
        "embalagem",
        "espaçadores de...",
        "estacas de fer...",
        "este é apenas ...",
        "estruturas",
        "estruturas met...",
        "estruturas por...",
        "fardo",
        "fardos com pan...",
        "ferragens",
        "ferramentas",
        "fertilizantes",
        "filme",
        "flakesmix de m...",
        "formas metalic...",
        "forno de padar...",
        "fracionado div...",
        "fundo liquido ...",
        "galoes",
        "granito rústic...",
        "grelha boca de...",
        "guarda corpo",
        "industrializad...",
        "iso-tanques",
        "jogo de peças",
        "kit de hidrant...",
        "kit fibra",
        "linha de pao d...",
        "madeira reflor...",
        "madeiras de pi...",
        "milho a granel",
        "minerio",
        "mistura pão de...",
        "misturador de ...",
        "modulos de bal...",
        "moenda",
        "mosaico de ped...",
        "mosaico pedra",
        "mudança - aloj...",
        "mudas de banan...",
        "oleo hydraulic",
        "painel de made...",
        "palete de ripa...",
        "paletes de mad...",
        "palio weekend",
        "papel",
        "para-choque",
        "parafusos",
        "pastilhas cera...",
        "peca agricola",
        "pecad",
        "pecas de aço",
        "peças de brinq...",
        "pecas de dois ...",
        "peças industri...",
        "pedra miracema",
        "perfil",
        "pesos de acade...",
        "piso cerâmicos",
        "placa cimentic...",
        "plastico fino",
        "plastico prens...",
        "pneus",
        "postes suporte...",
        "pre fabricado",
        "produto agríco...",
        "produto agrope...",
        "produtos",
        "pvc",
        "quimico",
        "ração",
        "ração a granel",
        "resto de mater...",
        "revestimento t...",
        "rolos de tela ...",
        "rosca de maqui...",
        "roupas etc",
        "sabão",
        "sacos de bexig...",
        "sacos de cimen...",
        "sacos de tampa...",
        "sacos semente",
        "scacos",
        "sobra de mudan...",
        "sofa feito de ...",
        "soro fisiologi...",
        "spa e deck com...",
        "sucata de plas...",
        "sucata plastic...",
        "tanque de ferr...",
        "tanque de poli...",
        "tanque polipro...",
        "tapete",
        "telha shingle",
        "telha simples ...",
        "teste",
        "torre de alumi...",
        "trilho barra ...",
        "tubo pvc",
        "tubos e chapas...",
        "tubos pead",
        "tubos seis met...",
        "um box - conta...",
        "vestuarios dvs",
        "viagens de log...",
        "viga de ferro ...",
        "moldes de isop...",
        "volumes",
        "abobora",
        "acm chapas",
        "açúcar em saco",
        "açucar paletiz...",
        "alinhamento",
        "amidos de milh...",
        "amostras de so...",
        "anilha de acad...",
        "anilhas para a...",
        "aparas de pape",
        "ardosia",
        "armario",
        "armário desmon...",
        "assento de cad...",
        "balde de tinta",
        "baldes",
        "baldes de cola",
        "banheira",
        "barricas",
        "bebedouro pilh...",
        "bebedouro plas...",
        "bebedouros - c...",
        "beg inbox",
        "big bag vazio",
        "big berg de bo...",
        "biscoito amost...",
        "bloco motor",
        "bobina de cabo...",
        "bobina de emba...",
        "bobina de ferr...",
        "bobina papelao...",
        "bobina rolo de...",
        "bobinas de plá...",
        "bobinas papel",
        "bomba de gasol...",
        "bombonas",
        "bonita de poli...",
        "borracha",
        "borracha granu...",
        "botinas",
        "brinquedos",
        "cabo",
        "cadeira odonto...",
        "cadeiras e mes...",
        "caixa de aço",
        "caixa de argam...",
        "caixa de gordu...",
        "caixa de isopo...",
        "caixa de plast...",
        "caixa de trans...",
        "caixa de vidro...",
        "caixa pequena",
        "caixa plastica",
        "caixa separado...",
        "caixaria vazia...",
        "caixas - diver...",
        "caixas com car...",
        "caixas com rou...",
        "caixas com sta...",
        "caixas de fibr...",
        "caixas de prod...",
        "caixas de seri...",
        "caixas pastilh...",
        "caixas pequena...",
        "caixinha",
        "camas casal bo...",
        "cantoneira",
        "cantoneiras de...",
        "carga fraciona...",
        "carga leve sho...",
        "caroço de algo...",
        "carrinho d ema...",
        "carrinho de be...",
        "carrinhos",
        "casa containe...",
        "cascos spas",
        "cavaletes",
        "chapa de aço e...",
        "chapas papelao",
        "chassi de grad...",
        "cilindro indus...",
        "cimento uso ge...",
        "climatizador",
        "climatizadores...",
        "cofre de aço",
        "colchões solte...",
        "complemento fe...",
        "complemento le...",
        "complemento um...",
        "completo de co...",
        "conjunto rodoc...",
        "conservador ve...",
        "container casa...",
        "container de d...",
        "container esta...",
        "container plas...",
        "containers mar...",
        "containner vaz...",
        "contêiner vazi...",
        "contrapesos",
        "coomplemento d...",
        "coridon",
        "correia transp...",
        "cosmeticos",
        "curitiba",
        "ddg",
        "deck itauba",
        "derivado de co...",
        "discos agrícol...",
        "distribuidor c...",
        "diversos''",
        "divresos",
        "dois paletes c...",
        "dois pallets m...",
        "dois volumes p...",
        "domo estrutura...",
        "e uma bacia de...",
        "e-bike turbo w...",
        "e-bike work w ...",
        "e-commerce",
        "eixo",
        "elcalipto",
        "embalagem de l...",
        "emplemento fig...",
        "equipe descarg...",
        "escora de obra",
        "esmalte cerami...",
        "espreguiçadeir...",
        "esteira de aca...",
        "esteiras",
        "esteiras de co...",
        "estrutura de a...",
        "eucalipto roli...",
        "fardo com pano...",
        "fardos de saco...",
        "farelo de milh...",
        "farelo ensacad...",
        "farinha",
        "farinha de oss...",
        "ferro e aço",
        "fertilizante c...",
        "fibra de vidro...",
        "filme stretch",
        "filme stretch ...",
        "filtro undustr...",
        "fita adesiva",
        "flange",
        "formas",
        "formas para pe...",
        "forro de madei...",
        "fosfato",
        "frasco",
        "freezer",
        "gabinetes",
        "garra floresta...",
        "goiania",
        "grades de isol...",
        "grades de piso",
        "gradil",
        "grama em placa",
        "grampo",
        "grampos",
        "granel",
        "guard rail",
        "guarita dupla",
        "hospitalar",
        "ibc",
        "ibc vazio",
        "ibcs",
        "impermeabiliza...",
        "lacre pino e b...",
        "ladrilho hidrá...",
        "lâminas de mad...",
        "latarel automo...",
        "latas vazias",
        "latas vazias -...",
        "letras acm",
        "livros",
        "lojinha banca",
        "lona",
        "longarina colu...",
        "lotacao",
        "macarrão ou bi...",
        "madeirites",
        "malha",
        "mangueiras",
        "mangueiras de ...",
        "mangueiras e c...",
        "manilha de aço...",
        "manta bidim",
        "manta de polie...",
        "materia de con...",
        "materia prima ...",
        "material de ac...",
        "material eletr...",
        "material para ...",
        "mercadoria div...",
        "mesa madeira",
        "mesa reunião",
        "milho grao",
        "modulos",
        "molde",
        "motor",
        "motor elétrico",
        "pacote de big ...",
        "palet",
        "palete de roda...",
        "palete medindo...",
        "palete pequeno",
        "paletea",
        "paletes pbr",
        "paletizada",
        "pallet de made...",
        "pallet de seme...",
        "pallet de toco",
        "pallets - geot...",
        "papel branco",
        "papel de pared...",
        "parafuso",
        "partes de mobi...",
        "passadeira de ...",
        "pastilhas",
        "pc",
        "peça coifa par...",
        "peça em ferro ...",
        "peça maquina",
        "peça maquina f...",
        "peça plástica",
        "pecaas",
        "pecas aviao",
        "pecas de ferro",
        "peças de imple...",
        "peças de plast...",
        "pecas de repos...",
        "peças de um ba...",
        "pecas diversos",
        "peças e ferram...",
        "pecas em palet...",
        "pedaços de md...",
        "pedra ardósia",
        "pedra paletriz...",
        "pedra para par...",
        "pedra são tomé",
        "pedras paletiz...",
        "pellet de made...",
        "perfil em rigi...",
        "perfis de seis...",
        "perfl",
        "pesado",
        "pesos",
        "piso",
        "pisos cerâmico...",
        "placas de conc...",
        "plastico canel...",
        "plástico e emb...",
        "plástico filme...",
        "polpa de tomat...",
        "porcelanato",
        "porcelanatos",
        "porteira de fe...",
        "postes de fibr...",
        "prego e grampo",
        "produtos alime...",
        "produtos de gr...",
        "promocional",
        "psletizdo",
        "quadro eletric...",
        "queijo ralado",
        "ração animal",
        "reciclagem",
        "recicláveis",
        "rede",
        "redutor",
        "reservatório d...",
        "resfriador",
        "resíduo",
        "resina",
        "ripa de madeir...",
        "rolo de mangue...",
        "saco de sement...",
        "sacos argamass...",
        "sacos de lixo ...",
        "sacos de pó de...",
        "sacos de semen...",
        "sacos sementes",
        "secadora",
        "sementes sacar...",
        "serra madeira",
        "silagem ensaca...",
        "silica gel",
        "silobolsa",
        "só gesso",
        "só um pallet j...",
        "socaminhao bau...",
        "sofás",
        "soja - seg ter...",
        "solado",
        "solar",
        "soro de leite",
        "spa",
        "strech filme ...",
        "sucata cobre",
        "sucata de bor...",
        "sucata de ferr...",
        "sucata ferrosa",
        "suco",
        "suporte para b...",
        "suporte pe de ...",
        "tambor",
        "tambores",
        "tampao de rua ...",
        "tampos metalic...",
        "tanque agua m...",
        "tanque de arla",
        "tanque de fibr...",
        "tanques de fer...",
        "tatames",
        "tecido",
        "tecidos",
        "telha metalica...",
        "telhas de cera...",
        "telhas de meta...",
        "telhas isoterm...",
        "telhas metálic...",
        "tijolo paletiz...",
        "tina de matura...",
        "tinta",
        "treliça de gal...",
        "tubo",
        "tubo de um met...",
        "tubos de pvc e...",
        "tubos e curvas",
        "tubos e outros",
        "uma poltrona",
        "uniport",
        "uréia",
        "validador",
        "válvula",
        "válvulas",
        "variado",
        "vaso sanitário...",
        "venezianas ind...",
        "viatura de com...",
        "vigas de ferro...",
        "vigotas proten...",
        "embalagens de ...",
        "espuma aglomer...",
        "frascos plásti...",
        "galão de litr...",
        "massa pva",
        "materiais de o...",
        "medio",
        "messa banco",
        "pallete",
        "placa de drayw...",
        "plastic",
        "tijolo refratá...",
        "trofeus",
        "unidade hidraú...",
        "um sofá",
        "bomba de argam...",
        "caçamba brook",
        "caixinha de pl...",
        "castanha do pa...",
        "chapa metalica",
        "dez sacos com ...",
        "dez sacos com...",
        "dez sacos de ...",
        "dezessete pufe...",
        "doca movel - d...",
        "dois colchonet...",
        "dois pacotes c...",
        "dois sacos de ...",
        "equipamento",
        "equipamento de...",
        "equipamentos d...",
        "peça metalica",
        "perfiladeira",
        "seis pacotes c...",
        "três sacos de ...",
        "carretas bazuk...",
        "conatiner rife...",
        "transformador"
    ];

    /**
     * Obter os fretes do usuário autenticado
     */
    public function meusFretes(Request $request)
    {
        $user = Auth::user();

        if (!$user) {
            return response()->json(['message' => 'Usuário não autenticado'], 401);
        }

        $query = Frete::where('user_id', $user->id);
        $query->orderBy('data_cadastro', 'desc');

        $perPage = $request->input('per_page', 15);
        $fretes = $query->paginate($perPage);

        return response()->json([
            'data' => $fretes->items(),
            'current_page' => $fretes->currentPage(),
            'per_page' => $fretes->perPage(),
            'total' => $fretes->total(),
            'last_page' => $fretes->lastPage(),
        ]);
    }

    /**
     * Display a listing of fretes.
     */
    public function index(Request $request)
    {
        $query = Frete::query();

        // Apply filters if provided
        if ($request->filled('origem')) {
            $query->where('origem', 'like', '%' . $request->origem . '%');
        }

        if ($request->filled('destino')) {
            $query->where('destino', 'like', '%' . $request->destino . '%');
        }

        if ($request->filled('estado_origem')) {
            $query->where('origem', 'like', '%' . $request->estado_origem . '%');
        }

        if ($request->filled('estado_destino')) {
            $query->where('destino', 'like', '%' . $request->estado_destino . '%');
        }

        if ($request->filled('tipo_carga')) {
            $query->where('tipo_carga', 'like', '%' . $request->tipo_carga . '%');
        }

        if ($request->filled('tipo_veiculo')) {
            $query->where('tipo_veiculo', 'like', '%' . $request->tipo_veiculo . '%');
        }

        if ($request->filled('empresa')) {
            $query->where('empresa', 'like', '%' . $request->empresa . '%');
        }

        if ($request->filled('start_date')) {
            $query->whereDate('data_cadastro', '>=', $request->start_date);
        }

        if ($request->filled('end_date')) {
            $query->whereDate('data_cadastro', '<=', $request->end_date);
        }

        // Apply sorting
        $sortColumn = $request->input('sort_column', 'data_cadastro');
        $sortOrder = $request->input('sort_order', 'desc');

        // Ensure the sort column is valid to prevent SQL injection
        $allowedColumns = ['id', 'frete_id', 'origem', 'destino', 'tipo_carga',
                           'empresa', 'preco', 'tipo_veiculo', 'data_cadastro'];

        if (!in_array($sortColumn, $allowedColumns)) {
            $sortColumn = 'data_cadastro';
        }

        $query->orderBy($sortColumn, $sortOrder);

        // Apply pagination
        $perPage = $request->input('per_page', 15);
        $fretes = $query->paginate($perPage);

        return response()->json([
            'data' => $fretes->items(),
            'current_page' => $fretes->currentPage(),
            'per_page' => $fretes->perPage(),
            'total' => $fretes->total(),
            'last_page' => $fretes->lastPage(),
        ]);
    }

    /**
     * Display the specified frete.
     */
    public function show($id)
    {
        $frete = Frete::findOrFail($id);
        return response()->json($frete);
    }

    /**
     * Store a new frete.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'frete_id' => 'nullable|string|max:50',
            'empresa' => 'required|string|max:255',
            'origem' => 'required|string|max:255',
            'destino' => 'required|string|max:255',
            'tipo_carga' => 'required|string|max:255',
            'distancia' => 'nullable|string|max:50',
            'tipo_veiculo' => 'nullable|string|max:100',
            'preco' => 'required|string|max:100',
            'descricao_pagamento' => 'nullable|string|max:255',
            'patrocinado' => 'nullable|in:Sim,Não',
            'tempo_publicacao' => 'nullable|string|max:50',
            'url_frete' => 'nullable|string|max:500',
            'contatos_whatsapp' => 'nullable|string',
            'contatos_celular' => 'nullable|string',
            'contatos_fixo' => 'nullable|string',
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        // Adicionar o ID do usuário atual ao pedido
        $data = $request->all();
        $data['user_id'] = Auth::id();

        // Criar o frete com o usuário associado
        $frete = Frete::create($data);

        return response()->json([
            'message' => 'Frete cadastrado com sucesso!',
            'frete' => $frete
        ], 201);
    }

    /**
     * Update a frete.
     */
    public function update(Request $request, $id)
    {
        $frete = Frete::findOrFail($id);

        // Verificar se o usuário é dono do frete
        if ($frete->user_id && $frete->user_id !== Auth::id() && !Auth::user()->isAdmin()) {
            return response()->json([
                'message' => 'Você não tem permissão para editar este frete.'
            ], 403);
        }

        $validator = Validator::make($request->all(), [
            'frete_id' => 'nullable|string|max:50',
            'empresa' => 'sometimes|required|string|max:255',
            'origem' => 'sometimes|required|string|max:255',
            'destino' => 'sometimes|required|string|max:255',
            'tipo_carga' => 'sometimes|required|string|max:255',
            'distancia' => 'nullable|string|max:50',
            'tipo_veiculo' => 'nullable|string|max:100',
            'preco' => 'sometimes|required|string|max:100',
            'descricao_pagamento' => 'nullable|string|max:255',
            'patrocinado' => 'nullable|in:Sim,Não',
            'tempo_publicacao' => 'nullable|string|max:50',
            'url_frete' => 'nullable|string|max:500',
            'contatos_whatsapp' => 'nullable|string',
            'contatos_celular' => 'nullable|string',
            'contatos_fixo' => 'nullable|string',
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        $frete->update($request->all());

        return response()->json([
            'message' => 'Frete atualizado com sucesso!',
            'frete' => $frete
        ]);
    }

    /**
     * Delete a frete.
     */
    public function destroy($id)
    {
        $frete = Frete::findOrFail($id);

        // Verificar se o usuário é dono do frete
        if ($frete->user_id && $frete->user_id !== Auth::id() && !Auth::user()->isAdmin()) {
            return response()->json([
                'message' => 'Você não tem permissão para excluir este frete.'
            ], 403);
        }

        $frete->delete();

        return response()->json(['message' => 'Frete removido com sucesso!']);
    }

    /**
     * Update only the distance of a frete.
     */
    public function updateDistance(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'distancia' => 'required|string|max:50',
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        $frete = Frete::findOrFail($id);

        // Verificar se é um admin ou se é o dono do frete
        if ($frete->user_id && $frete->user_id !== Auth::id() && !Auth::user()->isAdmin()) {
            return response()->json([
                'message' => 'Você não tem permissão para atualizar este frete.'
            ], 403);
        }

        $frete->distancia = $request->distancia;
        $frete->save();

        return response()->json([
            'message' => 'Distância atualizada com sucesso!',
            'distancia' => $frete->distancia
        ]);
    }
}
