<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Veiculo extends Model
{
    use HasFactory;

    /**
     * A tabela associada com o modelo.
     *
     * @var string
     */
    protected $table = 'veiculos';

    /**
     * Os atributos que são atribuíveis em massa.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'user_id',
        'placa',
        'antt',
        'tipo_veiculo',
        'marca',
        'modelo',
        'ano',
        'capacidade',
        'rastreado',
        'seguro',
        'localizacao_atual',
        'destino_interesse',
        'disponivel',
        'data_disponibilidade',
        'observacoes',
    ];

    /**
     * Os atributos que devem ser convertidos.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'rastreado' => 'boolean',
        'seguro' => 'boolean',
        'disponivel' => 'boolean',
        'data_disponibilidade' => 'date',
        'created_at' => 'datetime',
        'updated_at' => 'datetime',
    ];

    /**
     * Obtém o usuário que possui o veículo.
     */
    public function user()
    {
        return $this->belongsTo(User::class);
    }

    /**
     * Obtém o histórico de localizações do veículo.
     */
    public function localizacoes()
    {
        return $this->hasMany(VeiculoLocalizacao::class);
    }

    /**
     * Obtém os fretes compatíveis com este veículo.
     */
    public function fretesCompativeis()
    {
        return $this->belongsToMany(Frete::class, 'veiculos_fretes_match')
                    ->withPivot('score', 'notificado')
                    ->withTimestamps();
    }
}
