<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\FreteController;
use App\Http\Controllers\VeiculoController;
use App\Http\Controllers\Auth\RegistrationController;
use App\Http\Controllers\Auth\PasswordResetController;
use App\Http\Controllers\Auth\AuthenticationController;


// Authentication Routes
Route::prefix('auth')->group(function () {
    // Public routes
    Route::post('/register', [RegistrationController::class, 'register']);
    Route::post('/login', [AuthenticationController::class, 'login']);

    // Password reset routes
    Route::post('/forgot-password', [PasswordResetController::class, 'sendResetLink']);
    Route::post('/reset-password', [PasswordResetController::class, 'resetPassword']);

    // Protected routes (require authentication)
    Route::middleware('auth:sanctum')->group(function () {
        Route::post('/logout', [AuthenticationController::class, 'logout']);
        Route::get('/me', [AuthenticationController::class, 'me']);
    });
});


// Rotas protegidas (requerem autenticação)
Route::middleware('auth:sanctum')->group(function () {
    // Rota para 'meus fretes' - deve vir antes do apiResource para evitar conflitos
    Route::get('/meus-fretes', [FreteController::class, 'meusFretes']);

    // Rota para atualizar apenas a distância
    Route::patch('/fretes/{id}/distancia', [FreteController::class, 'updateDistance']);

    // Rotas padrão CRUD para fretes
    Route::apiResource('fretes', FreteController::class);

    // Rota para 'meus veículos'
    Route::get('/meus-veiculos', [VeiculoController::class, 'meusVeiculos']);

    // Rota para atualizar disponibilidade
    Route::patch('/veiculos/{id}/disponibilidade', [VeiculoController::class, 'atualizarDisponibilidade']);

    // Rota para atualizar localização
    Route::patch('/veiculos/{id}/localizacao', [VeiculoController::class, 'atualizarLocalizacao']);

    // Rota para fretes compatíveis
    Route::get('/veiculos/{id}/fretes-compativeis', [VeiculoController::class, 'fretesCompativeis']);

    // Rotas padrão CRUD para veículos
    Route::apiResource('veiculos', VeiculoController::class);
});
